import datetime
from .api_v1 import Entity as Entity, EntityList as EntityList, EntityRevision as EntityRevision, EntityType as EntityType, FileResource as FileResource, User as User
from .core import File as File, ViktorController as ViktorController
from .errors import EntityCreateError as EntityCreateError, EntityDeleteError as EntityDeleteError, EntityNotFoundError as EntityNotFoundError, EntityReviseError as EntityReviseError
from .parametrization import Parametrization as Parametrization
from _typeshed import Incomplete
from io import BytesIO, StringIO
from munch import Munch
from typing import Any, Callable, Iterator, Sequence

def mock_ParamsFromFile(controller: type[ViktorController]) -> Callable: ...
def mock_Storage(*, get: Sequence[File] = None, list: Sequence[dict[str, File]] = None) -> Callable: ...

class MockedEntityType(EntityType):
    def __init__(self, name: str = 'MockedEntityType', entity_type_id: int = 1) -> None: ...

class MockedEntityRevision(EntityRevision):
    def __init__(self, params: dict | Munch = None, created_date: datetime.datetime = None, entity_revision_id: int = 1) -> None: ...

class MockedUser(User):
    def __init__(self, *, first_name: str = 'John', last_name: str = 'Doe', email: str = 'john.doe@email.com', job_title: str = 'Employee', user_id: int = 1) -> None: ...

class MockedFileResource:
    @property
    def __class__(self) -> type: ...
    file: Incomplete
    filename: Incomplete
    def __init__(self, file: File = None, filename: str = 'mocked_file.txt') -> None: ...

class MockedEntity:
    @property
    def __class__(self) -> type: ...
    def __init__(self, *, entity_id: int = 1, name: str = 'Mocked Entity', entity_type: MockedEntityType = None, last_saved_params: dict | Munch = None, last_saved_summary: dict = None, get_file: File = None, parent: MockedEntity = None, children: Sequence['MockedEntity'] = None, siblings: Sequence['MockedEntity'] = None, revisions: Sequence[MockedEntityRevision] = None, invalid: bool = False, workspace_id: int = 1) -> None: ...
    @property
    def id(self) -> int: ...
    @property
    def name(self) -> str: ...
    @property
    def entity_type(self) -> MockedEntityType: ...
    @property
    def last_saved_params(self) -> Munch: ...
    @property
    def last_saved_summary(self) -> Munch: ...
    def get_file(self, *args: Any, **kwargs: Any) -> File: ...
    def parent(self, *args: Any, **kwargs: Any) -> MockedEntity: ...
    def children(self, *args: Any, entity_type_names: list[str] = None, **kwargs: Any) -> MockedEntityList: ...
    def siblings(self, *args: Any, entity_type_names: list[str] = None, **kwargs: Any) -> MockedEntityList: ...
    def create_child(self, entity_type_name: str, name: str, *args: Any, params: dict | Munch = None, **kwargs: Any) -> MockedEntity: ...
    def delete(self, *args: Any, **kwargs: Any) -> None: ...
    def rename(self, name: str, *args: Any, **kwargs: Any) -> MockedEntity: ...
    def revisions(self, *args: Any, **kwargs: Any) -> list[MockedEntityRevision]: ...
    def set_params(self, params: dict | Munch, *args: Any, **kwargs: Any) -> MockedEntity: ...

class MockedEntityList:
    @property
    def __class__(self) -> type: ...
    def __init__(self, entities: Sequence[MockedEntity], *, error: type[Exception] = None) -> None: ...
    def __len__(self) -> int: ...
    def __getitem__(self, index: int) -> MockedEntity: ...
    def __iter__(self) -> Iterator[MockedEntity]: ...

def mock_API(*, get_entity: Sequence[MockedEntity] | MockedEntity = None, create_child_entity: Sequence[MockedEntity] | MockedEntity = None, generate_upload_url: Sequence[dict] | dict = None, get_current_user: Sequence[MockedUser] | MockedUser = None, get_entities_by_type: Sequence[Sequence[MockedEntity]] | Sequence[MockedEntity] = None, get_entity_children: Sequence[Sequence[MockedEntity]] | Sequence[MockedEntity] = None, get_entity_siblings: Sequence[Sequence[MockedEntity]] | Sequence[MockedEntity] = None, get_root_entities: Sequence[Sequence[MockedEntity]] | Sequence[MockedEntity] = None, get_entity_parent: Sequence[MockedEntity] | MockedEntity = None, get_entity_revisions: Sequence[Sequence[MockedEntityRevision]] | Sequence[MockedEntityRevision] = None, get_entity_file: Sequence[File] | File = None, rename_entity: Sequence[MockedEntity] | MockedEntity = None, set_entity_params: Sequence[MockedEntity] | MockedEntity = None) -> Callable: ...
def mock_params(params: dict | File, parametrization: Parametrization | type[Parametrization], file_resources: dict[int, MockedFileResource] = None, entities: dict[int, MockedEntity] = None) -> Munch: ...
def mock_View(controller: type[ViktorController]) -> Callable: ...
def mock_SciaAnalysis(get_engineering_report: Sequence[BytesIO | File] | BytesIO | File = None, get_updated_esa_model: Sequence[BytesIO | File] | BytesIO | File = None, get_xml_output_file: Sequence[BytesIO | File] | BytesIO | File = None) -> Callable: ...
def mock_DSettlementAnalysis(get_output_file: dict[str, Sequence[BytesIO | File] | BytesIO | File] = None, get_sld_file: Sequence[StringIO | File] | StringIO | File = None) -> Callable: ...
def mock_DSheetPilingAnalysis(get_output_file: dict[str, Sequence[BytesIO | File] | BytesIO | File] = None) -> Callable: ...
def mock_DStabilityAnalysis(get_output_file: dict[str, Sequence[File] | File] = None) -> Callable: ...
def mock_DGeoStabilityAnalysis(get_output_file: dict[str, Sequence[BytesIO | File] | BytesIO | File] = None) -> Callable: ...
def mock_DFoundationsAnalysis(get_output_file: dict[str, Sequence[BytesIO | File] | BytesIO | File] = None) -> Callable: ...
def mock_GRLWeapAnalysis(get_output_file: Sequence[BytesIO | File] | BytesIO | File = None) -> Callable: ...
def mock_IdeaRcsAnalysis(get_output_file: Sequence[BytesIO | File] | BytesIO | File = None, get_idea_rcs_file: Sequence[BytesIO | File] | BytesIO | File = None) -> Callable: ...
def mock_RobotAnalysis(get_model_file: Sequence[File] | File = None, get_results: Sequence[dict] | dict = None) -> Callable: ...
def mock_AxisVMAnalysis(get_model_file: Sequence[BytesIO | File] | BytesIO | File = None, get_result_file: Sequence[BytesIO | File] | BytesIO | File = None, get_results: Sequence[dict] | dict = None) -> Callable: ...
def mock_GenericAnalysis(get_output_file: dict[str, Sequence[BytesIO | File] | BytesIO | File] = None) -> Callable: ...
CellValue = str | int | float | bool

def mock_Excel(get_named_cell_result: dict[str, Sequence[CellValue] | CellValue] = None, get_direct_cell_result: dict[tuple[str, str, int], Sequence[CellValue] | CellValue] = None, get_filled_template: Sequence[File] | File = None) -> Callable: ...
def mock_RFEMAnalysis(get_model: Sequence[File | BytesIO] | File | BytesIO = None, get_result: dict[int, Sequence[File | BytesIO] | File | BytesIO] = None) -> Callable: ...
